==> openGion6.8.6.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE53S.sql <==
/****************************************************************************/
/* GE53 ( 振分条件ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2017/07/18 08:42:12                                            */
/****************************************************************************/

CREATE TABLE GE53 (
   SYSTEM_ID        varchar (  10 )                         NOT NULL            /*  10 ｼｽﾃﾑID       */
 , JOKEN            varchar (  20 )                         NOT NULL            /*  20 振分条件     */
 , FGRUN            varchar (   1 )                         NOT NULL            /*  30 実行方法     */
 , PRTID            varchar (  20 )                                             /*  40 ﾌﾟﾘﾝﾀID      */
 , LANG             varchar (   2 )                                             /*  50 言語         */
 , PRGDIR           varchar ( 100 )                         NOT NULL            /*  60 実行PGDIR    */
 , PRGFILE          varchar (  50 )                         NOT NULL            /*  70 実行PGﾌｧｲﾙ名 */
 , COMMENTS         varchar ( 500 )                                             /*  80 ｺﾒﾝﾄ         */
 , DMN_GRP          varchar (  20 )     DEFAULT 'DG0000'    NOT NULL            /*  90 ﾃﾞｰﾓﾝｸﾞﾙｰﾌﾟ  */
 , DMN_TIME         INTEGER             DEFAULT 5           NOT NULL            /* 100 ﾃﾞｰﾓﾝ間隔    */
 , RELEASE_NOTES    varchar ( 120 )                                             /* 110 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         varchar (  20 )                                             /* 120 設変番号     */
 , OUT_DIR          varchar ( 100 )                                             /* 130 出力ﾌｧｲﾙDIR  */
 , OUT_FILE         varchar (  50 )                                             /* 140 出力ﾌｧｲﾙ名   */
 , JKN_GRP          varchar (  20 )                                             /* 150 条件ｸﾞﾙｰﾌﾟ   */
 , FGJ              varchar (   1 )     DEFAULT '1'         NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            varchar (  14 )                                             /* 820 登録日時     */
 , PGSET            varchar (  10 )                                             /* 830 作成PG       */
 , PGPSET           varchar (  10 )                                             /* 840 作成親PG     */
 , USRSET           varchar (  10 )                                             /* 850 作成社員     */
 , DYUPD            varchar (  14 )                                             /* 860 更新日時     */
 , PGUPD            varchar (  10 )                                             /* 870 更新PG       */
 , PGPUPD           varchar (  10 )                                             /* 880 更新親PG     */
 , USRUPD           varchar (  10 )                                             /* 890 更新者       */
);

==> openGion7.2.0.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE53S.sql <==
/****************************************************************************/
/* GE53 ( 振分条件ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2018/09/28 16:03:40                                            */
/****************************************************************************/

CREATE TABLE GE53 (
   SYSTEM_ID        varchar (  10 )                         NOT NULL            /*  10 ｼｽﾃﾑID       */
 , JOKEN            varchar (  20 )                         NOT NULL            /*  20 振分条件     */
 , FGRUN            varchar (   1 )                         NOT NULL            /*  30 実行方法     */
 , PRTID            varchar (  20 )                                             /*  40 ﾌﾟﾘﾝﾀID      */
 , LANG             varchar (   2 )                                             /*  50 言語         */
 , PRGDIR           varchar ( 100 )                         NOT NULL            /*  60 実行PGDIR    */
 , PRGFILE          varchar (  50 )                         NOT NULL            /*  70 実行PGﾌｧｲﾙ名 */
 , COMMENTS         varchar ( 500 )                                             /*  80 ｺﾒﾝﾄ         */
 , DMN_GRP          varchar (  20 )     DEFAULT 'DG0000'    NOT NULL            /*  90 ﾃﾞｰﾓﾝｸﾞﾙｰﾌﾟ  */
 , DMN_TIME         INTEGER             DEFAULT 5           NOT NULL            /* 100 ﾃﾞｰﾓﾝ間隔    */
 , RELEASE_NOTES    varchar ( 120 )                                             /* 110 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         varchar (  20 )                                             /* 120 設変番号     */
 , OUT_DIR          varchar ( 100 )                                             /* 130 出力ﾌｧｲﾙDIR  */
 , OUT_FILE         varchar (  50 )                                             /* 140 出力ﾌｧｲﾙ名   */
 , JKN_GRP          varchar (  20 )                                             /* 150 条件ｸﾞﾙｰﾌﾟ   */
 , FGJ              varchar (   1 )     DEFAULT '1'         NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            varchar (  14 )                                             /* 820 登録日時     */
 , PGSET            varchar (  10 )                                             /* 830 作成PG       */
 , PGPSET           varchar (  10 )                                             /* 840 作成親PG     */
 , USRSET           varchar (  10 )                                             /* 850 作成者       */
 , DYUPD            varchar (  14 )                                             /* 860 更新日時     */
 , PGUPD            varchar (  10 )                                             /* 870 更新PG       */
 , PGPUPD           varchar (  10 )                                             /* 880 更新親PG     */
 , USRUPD           varchar (  10 )                                             /* 890 更新者       */
);
